@@ -3,7 +3,7 @@ use quick_protobuf::deserialize_from_slice;
 use solana_program::account_info::AccountInfo;
 use solana_program::program_error::ProgramError;
 
-pub use switchboard_utils::{FastRoundResultAccountData, FastRoundResult, fast_parse_switchboard_result};
+pub use switchboard_utils_bm::{FastRoundResultAccountData, FastRoundResult, fast_parse_switchboard_result};
 pub use switchboard_protos::protos::aggregator_state::AggregatorState;
 pub use switchboard_protos::protos::aggregator_state::mod_AggregatorState;
 pub use switchboard_protos::protos::aggregator_state::RoundResult;
